@@ -26,9 +26,6 @@ end
 
 class Puppet::Server::Logger
   def self.init_logging
-    # Crank Puppet's log level all the way up and just control it via logback.
-    Puppet::Util::Log.level = :debug
-
     Puppet::Util::Log.newdestination(:logback)
   end
 end
